namespace Kit.Helpers.Routes
{
    public interface IEndPointFluent<TRouteFluent>
    {
        TRouteFluent NeedHttpGet(bool required = true);
        TRouteFluent NeedHttpPost(bool required = true);
        TRouteFluent NeedSecurityKey(string securityKeyName);
        TRouteFluent WithDefaults(object defaults);
        TRouteFluent WithConstraints(object constraints);
        TRouteFluent WithNamespaces(string[] namespaces);
        TRouteFluent WithDataTokens(object dataTokens);
    }
}